<?php
class obox_portfolio_widget extends WP_Widget {
	/** constructor */
	function __construct() {
		$widget_ops = array('classname' => 'obox_portfolio_widget', 'description' => __('Display portfolio content in a multi-column layout on your home page.', 'ocmx'));
		parent::__construct('obox_portfolio_widget', __("(Obox) Portfolio Widget", "ocmx"), $widget_ops);
	}
	/** @see WP_Widget::widget */
	function widget( $args, $instance ) {

		// Turn $args array into variables.
		extract( $args );

		// Turn $instance array into variables
		$instance_defaults = array ( 'post_thumb' => 1, 'post_count' => 4, 'layout_columns' => 2, 'image_dimensions' => '1-1' , 'title_align' => 'leftalign' );
		$instance_args = wp_parse_args( $instance, $instance_defaults );
		extract( $instance_args, EXTR_SKIP );

		$args = array(
			"post_type" => 'portfolio',
			"posts_per_page" => $post_count,
		);

		if($post_category != "0") :
			$args['tax_query'] = array(
					array(
						"taxonomy" => 'portfolio-category',
						"field" => "slug",
						"terms" => $post_category
					)
				);
		endif;


		// Set the post order
		if(isset($post_order_by)) :
			$args['order'] = $post_order;
			$args['orderby'] = $post_order_by;
		endif;

		// Main Post Query
		$loop = new WP_Query($args);

		// Widget Background CSS
		if( isset( $background_image ) ) { $css = obox_widget_generate_css( array( "widget_id" => $widget_id , "input" => $background_image , "type" => "background" ) ); }

		// Widget Title & Excerpt CSS
		if( isset( $text_color ) ) { $title_excerpt_css =  obox_widget_generate_css(
				array(
					"widget_id" => $widget_id ,
					"input" => $text_color ,
					"type" => "color" ,
					"selectors" => array(
						".widgettitle" ,
						".widget-description" ,
						".column .content h4",
						".column .content h4.post-title"
					)
				)
			); } ?>

		<li class="content-widget portfolio-content-widget widget <?php echo $title_align; ?> clearfix" id="<?php echo $widget_id; ?>">

			<div class="title-content clearfix">
				<?php if(isset($title) && $title != "") : ?>
					<h3 class="widgettitle ">
						<?php echo $title; ?>
					</h3>
				<?php endif; ?>

				<?php if(isset($widget_description) && $widget_description !='') : ?>
					<p class="widget-description"><?php echo $widget_description; ?></p>
				<?php endif; ?>

				<?php if( isset( $category_cloud ) && $category_cloud == "on" ) {
					$cat_list = get_terms("portfolio-category", "orderby=count&hide_empty=1");
					if ($cat_list != "") { ?>
	            				<ul class="category-cloud clearfix">
	            					<li class="active"><a href="#all" data-filter="*" data-container-div-id="#<?php echo $widget_id; ?>"><?php _e( 'All' , 'ocmx' ); ?></a></li>
							<?php foreach($cat_list as $tax) { ?>
								<li>
									<a href="#<?php echo get_term_link($tax->slug, "portfolio-category"); ?>" data-filter="<?php echo '.' . $tax->slug; ?>" data-container-div-id="#<?php echo $widget_id; ?>"><?php echo $tax->name; ?></a>
								</li>
							<?php }; ?>
						</ul>
	        				<?php }
				} ?>
			</div>

			<div class="expand-portfolio no_display" id="expand-<?php echo $widget_id; ?>"></div>

			<ul class="content-widget-item portfolio clearfix <?php echo $layout_columns; ?>">

				<?php while ( $loop->have_posts() ) : $loop->the_post();
					global $post;
					$width = 660;
					$height = 495;
					if( $layout_columns == 'one' ) {
						$resizer = 'full';
					} else {
						$resizer = $image_dimensions . '-medium';
					}
					$link = get_permalink($post->ID);
					$image_args  = array('postid' => $post->ID, 'width' => $width, 'height' => $height, 'hide_href' => false, 'exclude_video' => $post_thumb, 'wrap' => 'div', 'wrap_class' => 'post-image fitvid', 'imglink' => false, 'resizer' => $resizer );
					$image = get_obox_media($image_args);
					$terms = wp_get_post_terms( $post->ID, 'portfolio-category', $args );
					$term_list = array();
					if( !empty( $terms ) ) {
						foreach( $terms as $term ){
							$term_list[] = $term->slug;
						}
					}?>

					<li class="column masonry-column <?php echo implode( $term_list, " " ) ; ?>" data-post-id="<?php echo the_ID(); ?>" data-container-div-id="#<?php echo $widget_id; ?>" data-categories="<?php echo implode( $term_list, "," ) ; ?>">
						<?php if(isset($image) && $image !=''): ?>
							<div class="portfolio-image">
								<?php echo $image; ?>
								<div class="overlay-info">
									<div class="overlay-cta">
										<span class="icon-search">
											<a href="#"></a>
										</span>
										<h1><a href="<?php the_permalink(); ?>"><?php the_title(); ?></a></h1>
									</div>
								</div>
							</div>
						<?php endif; ?>
					</li>
				<?php endwhile; ?>
			</ul>
		</li>

<?php
	}

	/** @see WP_Widget::update */
	function update($new_instance, $old_instance) {
		return $new_instance;
	}

	/** @see WP_Widget::form */
	function form($instance) {

		// Turn $instance array into variables
		$instance_defaults = array ( 'post_thumb' => 1, 'postfilter' => '0', 'post_count' => 4, 'layout_columns' => 'four', 'image_dimensions' => '1-1', 'title_align' => 'leftalign' );
		$instance_args = wp_parse_args( $instance, $instance_defaults );
		extract( $instance_args, EXTR_SKIP ); ?>

	<p>
		<label for="<?php echo $this->get_field_id('title'); ?>"><?php _e("Title", "ocmx"); ?><input class="widefat" id="<?php echo $this->get_field_id('title'); ?>" name="<?php echo $this->get_field_name('title'); ?>" type="text" value="<?php if(isset($title)) echo $title; ?>" /></label>
	</p>

	<p>
		<label for="<?php echo $this->get_field_id('widget_description'); ?>">
			<?php _e("Description", "ocmx"); ?>
			<textarea class="widefat" rows="5" id="<?php echo $this->get_field_id('widget_description'); ?>" name="<?php echo $this->get_field_name('widget_description'); ?>"><?php if(isset($widget_description)) echo $widget_description; ?></textarea>
		</label>
	</p>

	<?php $alignment = array('leftalign' => 'Left Align', 'centeralign' => 'Centered', 'rightalign' => 'Right Align'); ?>
	<p>
		<label for="<?php echo $this->get_field_id('title_align'); ?>"><?php _e("Title & Description Alignment", "ocmx"); ?></label>
		<select size="1" class="widefat" id="<?php echo $this->get_field_id('title_align'); ?>" name="<?php echo $this->get_field_name('title_align'); ?>">
			<?php foreach($alignment as $value => $label) : ?>
				<option <?php if($title_align == $value) : ?>selected="selected"<?php endif; ?> value="<?php echo $value; ?>"><?php echo $label; ?></option>
			<?php endforeach; ?>
		</select>
	</p>

	<hr />

	<p>
		<label for="<?php echo $this->get_field_id('post_category'); ?>">Category</label>
		<?php $cat_list = get_terms("portfolio-category", "orderby=count&hide_empty=0");?>

		<select size="1" class="widefat" id="<?php echo $this->get_field_id("post_category"); ?>" name="<?php echo $this->get_field_name("post_category"); ?>">
			<option <?php if($post_category == 0){echo "selected=\"selected\"";} ?> value="0"><?php _e( 'All' , 'ocmx' ); ?></option>
			<?php foreach($cat_list as $tax) :
				$use_value =  $tax->name;
				if($use_value == $post_category)
					{$selected = " selected='selected' ";}
				else
					{$selected = " ";} ?>
				<option <?php echo $selected; ?> value="<?php echo $use_value; ?>"><?php echo $tax->name; ?></option>
			<?php endforeach; ?>
		 </select>
	</p>
	<?php if( 0 == $post_category ) { ?>
	<p>
		<label for="<?php echo $this->get_field_id('category_cloud'); ?>">
			<input type="checkbox" <?php if(isset($category_cloud) && $category_cloud == "on") : ?>checked="checked"<?php endif; ?> id="<?php echo $this->get_field_id('category_cloud'); ?>" name="<?php echo $this->get_field_name('category_cloud'); ?>">
			<?php _e("Show Category Filter", "ocmx"); ?>
		</label>
	</p>
	<?php } ?>
	<?php
	// Setup the column layouts
	$layout_options = array('one' => '1', 'two' => '2', 'three' => '3', 'four' => '4', 'five' => '5' , 'six' => '6' );?>
	<p>
		<label for="<?php echo $this->get_field_id('layout_columns'); ?>"><?php _e("Column Layout", "ocmx"); ?></label>
		<select size="1" class="widefat" id="<?php echo $this->get_field_id('layout_columns'); ?>" name="<?php echo $this->get_field_name('layout_columns'); ?>">
			<?php foreach($layout_options as $value => $label) : ?>
				<option <?php if($layout_columns == $value) : ?>selected="selected"<?php endif; ?> value="<?php echo $value; ?>"><?php echo $label; ?></option>
			<?php endforeach; ?>
		</select>
	</p>

	<p>
		<label for="<?php echo $this->get_field_id('post_count'); ?>"><?php _e("Post Count", "ocmx"); ?></label>
		<select size="1" class="widefat" id="<?php echo $this->get_field_id('post_count'); ?>" name="<?php echo $this->get_field_name('post_count'); ?>">
			<?php $i = 1;
			while($i < 25) :?>
				<option <?php if($post_count == $i) : ?>selected="selected"<?php endif; ?> value="<?php echo $i; ?>"><?php echo $i; ?></option>
			<?php if($i < 1) :
					$i++;
				else:
					$i=($i+1);
				endif;
			endwhile; ?>
		</select>
	</p>

	<?php if( $layout_columns != 'one' ) {
		// Setup the column layouts
		$image_dimension_options = array( '4-3' => '4:3', '1-1' => 'Square' );?>
		<p>
			<label for="<?php echo $this->get_field_id('image_dimensions'); ?>"><?php _e("Image Dimensions", "ocmx"); ?></label>
			<select size="1" class="widefat" id="<?php echo $this->get_field_id('image_dimensions'); ?>" name="<?php echo $this->get_field_name('image_dimensions'); ?>">
				<?php foreach($image_dimension_options as $value => $label) : ?>
					<option <?php if($image_dimensions == $value) : ?>selected="selected"<?php endif; ?> value="<?php echo $value; ?>"><?php echo $label; ?></option>
				<?php endforeach; ?>
			</select>
		</p>
	<?php } ?>
	<?php  // Setup the order values
	$order_params = array("date" => "Post Date", "title" => "Post Title", "rand" => "Random",  "comment_count" => "Comment Count",  "menu_order" => "Menu Order"); ?>
	<p>
		<label for="<?php echo $this->get_field_id('post_order_by'); ?>"><?php _e("Order By", "ocmx"); ?></label>
		<select size="1" class="widefat" id="<?php echo $this->get_field_id('post_order_by'); ?>" name="<?php echo $this->get_field_name('post_order_by'); ?>">
			<?php foreach($order_params as $value => $label) :?>
				<option  <?php if(isset($post_order_by) && $post_order_by == $value){echo "selected=\"selected\"";} ?> value="<?php echo $value; ?>"><?php echo $label; ?></option>
			<?php endforeach;?>
		</select>
	</p>
	<p>
		<label for="<?php echo $this->get_field_id('post_order'); ?>"><?php _e("Order", "ocmx"); ?></label>
		<select size="1" class="widefat" id="<?php echo $this->get_field_id('post_order'); ?>" name="<?php echo $this->get_field_name('post_order'); ?>">
			<option <?php if(!isset($post_order) || isset($post_order) && $post_order == "DESC") : ?>selected="selected"<?php endif; ?> value="DESC"><?php _e("Descending", 'ocmx'); ?></option>
			<option <?php if(isset($post_order) && $post_order == "ASC") : ?>selected="selected"<?php endif; ?> value="ASC"><?php _e("Ascending", 'ocmx'); ?></option>
		</select>
	</p>


	<p>
		<label for="<?php echo $this->get_field_id('post_thumb'); ?>"><?php _e("Show Images or Videos?", "ocmx"); ?></label>
		<select size="1" class="widefat" id="<?php echo $this->get_field_id('post_thumb'); ?>" name="<?php echo $this->get_field_name('post_thumb'); ?>">
				<option <?php if($post_thumb == "none") : ?>selected="selected"<?php endif; ?> value="none"><?php _e("None", "ocmx"); ?></option>
				<option <?php if($post_thumb == "1") : ?>selected="selected"<?php endif; ?> value="1"><?php _e("Featured Thumbnails", "ocmx"); ?></option>
				<option <?php if($post_thumb == "0") : ?>selected="selected"<?php endif; ?> value="0"><?php _e("Videos", "ocmx"); ?></option>
		</select>
	</p>

	<p>
		<label for="<?php echo $this->get_field_id('show_titles'); ?>">
			<input type="checkbox" <?php if(isset($show_titles) && $show_titles == "on") : ?>checked="checked"<?php endif; ?> id="<?php echo $this->get_field_id('show_titles'); ?>" name="<?php echo $this->get_field_name('show_date'); ?>">
			<?php _e("Show Titles", "ocmx"); ?>
		</label>
	</p>

	<hr />
	<h4><?php _e( 'Widget Styling' , 'ocmx' ); ?></h4>

	<p>
		<?php if ( !isset( $background_image ) ) $background_image = 0;

		obox_widget_image_control( 'Background Color &amp; Image' , $this->get_field_name("background_image") , $background_image ); ?>
	</p>
	<p>
		<?php if (! isset( $text_color ) ) $text_color = 0;

		obox_widget_color_control( 'Title &amp; Excerpt Color' , $this->get_field_name("text_color") , $text_color ); ?>
	</p>

<?php
	} // form

}// class

//This sample widget can then be registered in the widgets_init hook:

// register FooWidget widget
add_action('widgets_init', create_function('', 'return register_widget("obox_portfolio_widget");'));

?>