<?php
class obox_text_widget extends WP_Widget {
	/** constructor */

	function __construct() {
		$widget_ops = array('classname' => 'widget_text', 'description' => __('"Custom text widget with the Obox widget styling."'));
		$control_ops = array('width' => 400, 'height' => 350);
		parent::__construct('obox_text_widget', __("(Obox) Text Widget", "ocmx"), $widget_ops, $control_ops);
	}

	/** @see WP_Widget::widget */
	function widget( $args, $instance ) {

		// Turn $args array into variables.
		extract( $args );

		// Turn $instance array into variables
		$instance_defaults = array ( 'title_align' => 'centeralign' );
		$instance_args = wp_parse_args( $instance, $instance_defaults );
		extract( $instance_args, EXTR_SKIP );

		$title = apply_filters( 'widget_title', empty( $instance['title'] ) ? '' : $instance['title'], $instance, $this->id_base );
		$text = apply_filters( 'widget_text', empty( $instance['text'] ) ? '' : $instance['text'], $instance );

		// Widget Background CSS
		if( isset( $background_image ) ) $css = obox_widget_generate_css( array( "widget_id" => $widget_id , "input" => $background_image , "type" => "background" ) );

		// Widget Title & Excerpt CSS
		if( isset( $text_color ) ) $title_excerpt_css =  obox_widget_generate_css( array( "widget_id" => $widget_id , "input" => $text_color , "type" => "color" , "selectors" => array ( ".widgettitle" , ".textwidget") ) ); ?>

		<li class="widget widget_text <?php echo $title_align; ?>" id="<?php echo $widget_id; ?>">

			<?php if(isset($title) && $title != "") : ?>
				<h3 class="widgettitle">
					<?php echo $title; ?>
				</h3>
			<?php endif; ?>

			<?php if(isset($text) && $text !='') : ?>
				<div class="textwidget"><?php echo !empty( $instance['filter'] ) ? wpautop( $text ) : $text; ?></div>
			<?php endif; ?>
		</li>

<?php
	}

	/** @see WP_Widget::update */

	function update( $new_instance, $old_instance ) {
		$instance = $old_instance;
		$instance['title'] = strip_tags($new_instance['title']);
		if ( current_user_can('unfiltered_html') )
			$instance['text'] =  $new_instance['text'];
		else
			$instance['text'] = stripslashes( wp_filter_post_kses( addslashes($new_instance['text']) ) ); // wp_filter_post_kses() expects slashed
		$instance['filter'] = isset($new_instance['filter']);
		$instance['background_image'] = $new_instance['background_image'];
		$instance['text_color'] = $new_instance['text_color'];
		$instance['title_align'] = $new_instance['title_align'];

		return $instance;
	}

	/** @see WP_Widget::form */
	function form($instance) {

		// Turn $instance array into variables
		$instance_defaults = array ( 'title_align' => 'centeralign' );
		$instance_args = wp_parse_args( $instance, $instance_defaults );
		extract( $instance_args, EXTR_SKIP ); ?>

	<p>
		<label for="<?php echo $this->get_field_id('title'); ?>"><?php _e("Title", "ocmx"); ?><input class="widefat" id="<?php echo $this->get_field_id('title'); ?>" name="<?php echo $this->get_field_name('title'); ?>" type="text" value="<?php if( isset($title) ) echo $title; ?>" /></label>
	</p>

	<p>
		<label for="<?php echo $this->get_field_id('widget_description'); ?>">
			<?php _e("Description", "ocmx"); ?>
			<textarea class="widefat" rows="16" cols="20" id="<?php echo $this->get_field_id('text'); ?>" name="<?php echo $this->get_field_name('text'); ?>"><?php if( isset($text) ) echo $text; ?></textarea>


		</label>
	</p>

	<p><input id="<?php echo $this->get_field_id('filter'); ?>" name="<?php echo $this->get_field_name('filter'); ?>" type="checkbox" <?php checked(isset($instance['filter']) ? $instance['filter'] : 0); ?> />&nbsp;<label for="<?php echo $this->get_field_id('filter'); ?>"><?php _e('Automatically add paragraphs'); ?></label></p>

	<?php $alignment = array('leftalign' => 'Left Align', 'centeralign' => 'Centered', 'rightalign' => 'Right Align'); ?>
	<p>
		<label for="<?php echo $this->get_field_id('title_align'); ?>"><?php _e("Title & Description Alignment", "ocmx"); ?></label>
		<select size="1" class="widefat" id="<?php echo $this->get_field_id('title_align'); ?>" name="<?php echo $this->get_field_name('title_align'); ?>">
			<?php foreach($alignment as $value => $label) : ?>
				<option <?php if(isset($title_align) && $title_align == $value) : ?>selected="selected"<?php endif; ?> value="<?php echo $value; ?>"><?php echo $label; ?></option>
			<?php endforeach; ?>
		</select>
	</p>

	<hr />
	<h4><?php _e( 'Widget Styling' , 'ocmx' ); ?></h4>
	<p>
		<?php if ( !isset( $background_image ) ) $background_image = 0;

		obox_widget_image_control( 'Background Color &amp; Image' , $this->get_field_name("background_image") , $background_image ); ?>
	</p>
	<p>
		<?php if (! isset( $text_color ) ) $text_color = 0;

		obox_widget_color_control( 'Title &amp; Excerpt Color' , $this->get_field_name("text_color") , $text_color ); ?>
	</p>

<?php
	} // form

}// class

//This sample widget can then be registered in the widgets_init hook:

// register FooWidget widget
add_action('widgets_init', create_function('', 'return register_widget("obox_text_widget");'));
add_filter('widget_text', 'do_shortcode');